radar_tools API
====================================

.. automodule:: domutils.radar_tools.get_instantaneous
   :members: 

.. automodule:: domutils.radar_tools.get_accumulation
   :members: 

.. automodule:: domutils.radar_tools.exponential_zr
   :members: 

.. automodule:: domutils.radar_tools.read_h5_composite
   :members: 

.. automodule:: domutils.radar_tools.read_fst_composite
   :members: 

.. automodule:: domutils.radar_tools.median_filter
   :members: 



